pub struct ConfigSpecRequest {
pub sdk_key: String,
pub since_time: Option<u64>,
pub version: Option<i32>,
pub zstd_dict_id: Option<String>,
}Fields
sdk_key: Stringsince_time: Option<u64>This was a typo but you can’t delete it
version: Option<i32>zstd_dict_id: Option<String>Implementations
Sourceimpl ConfigSpecRequest
impl ConfigSpecRequest
Sourcepub fn version(&self) -> ApiVersion
pub fn version(&self) -> ApiVersion
Returns the enum value of version, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_version(&mut self, value: ApiVersion)
pub fn set_version(&mut self, value: ApiVersion)
Sets version to the provided enum value.
Sourcepub fn zstd_dict_id(&self) -> &str
pub fn zstd_dict_id(&self) -> &str
Returns the value of zstd_dict_id, or the default value if zstd_dict_id is unset.
Sourcepub fn since_time(&self) -> u64
pub fn since_time(&self) -> u64
Returns the value of since_time, or the default value if since_time is unset.